@@ -211,17 +211,21 @@ class Daisi:
                 self.name = r.json()["name"]
                 self.id = daisi_id
         else:
-            logger.info(f"Calling {self.new_url}/search with query {daisi_id}")
+            logger.info(f"Calling {self.new_url}/connect?name={daisi_id}")
             r = self.session.get(
-                f"{self.new_url}/search",
-                params={"term[]": [daisi_id], "pageSize": 1, "page": 1},
+                f"{self.new_url}/connect",
+                params={"name": daisi_id},
             )
             result = r.json()
 
-            if result and result["success"] and result["data"]["data"]:
+            if r.status_code == 200:
+                result = r.json()
+
                 self.name = daisi_id
-                daisi_id = result["data"]["data"][0]["id"]
+                daisi_id = result["id"]
+
                 logger.info(f"Found existing Daisi: {daisi_id}")
+                
                 self.id = daisi_id
             else:
                 # TODO: Handle git repo connection here
@@ -329,16 +333,18 @@ class Daisi:
         )
         result = r.json()
 
-        return_list = []
-        for daisi in result["data"][0]["data"]:
-            return_list.append(
-                {
-                    "id": daisi["id"],
-                    "name": daisi["name"],
-                    "description": daisi["description"],
-                }
-            )
+        daisi_list = []
+        for section_data in result['data']:
+            if section_data['name'] != 'Topics':
+                section_request = requests.get(f'{base_url}{daisi_new_route}/section/{section_data["id"]}',
+                                               params={"pageSize": 10000, "page": 1},
+                                               headers=headers)
+                section_daisies = section_request.json()
+                daisi_list.extend([{'id': daisi['id'],
+                                    'name': daisi['name'],
+                                    'description': daisi['description']}
+                                   for daisi in section_daisies['data']['data']])
 
-        final_return = sorted(return_list, key=lambda x: x["name"])
+        daisi_list = sorted(daisi_list, key=lambda x: x["name"])
 
-        return final_return
+        return daisi_list
